FlutterSoundFFmpegConfig class

Constructors

FlutterSoundFFmpegConfig(Logger aLogger)

Properties

hashCode → int
The hash code for this object.
no setterinherited
logger ↔ Logger
The FlutterSoundFFmpegConfig Logger
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statisticsCallback ↔ StatisticsCallback?
getter/setter pair

Methods

disableLogs() → Future<void>
Disables log functionality of the library. Logs will not be p rinted to console and log callback will be disabled. Note that log functionality is enabled by default.
disableRedirection() → Future<void>
Disables log and statistics redirection.
disableStatistics() → Future<void>
Disables statistics functionality of the library. Statistics callback will be disabled but the last received statistics data will be still available. Note that statistics functionality is enabled by default.
enableLogs() → Future<void>
Enables log events.
enableRedirection() → Future<void>
Enables log and statistics redirection.
enableStatistics() → Future<void>
Enables statistics events.
enableStatisticsCallback(StatisticsCallback newCallback) → void
Sets a callback to redirect FFmpeg logs. newCallback is the new log callback function, use null to disable a previously defined callback. Sets a callback to redirect FFmpeg statistics. newCallback is the new statistics callback function, use null to disable a previously defined callback.
eventToStatistics(Map eventMap) → FlutterSoundStatistics?
Creates a new Statistics instance from event map.
getExternalLibraries() → Future<List?>
Returns supported external libraries.
getFFmpegVersion() → Future<String?>
Returns FFmpeg version bundled within the library.
getLastCommandOutput() → Future<String?>
Returns the log output of last executed command. Please note that disableRedirection() method also disables this functionality.
getLastReceivedStatistics() → Future<FlutterSoundStatistics?>
Returns the last received Statistics instance.
getLastReturnCode() → Future<int?>
Returns return code of the last executed command.
getLogLevel() → Future<int?>
Returns log level.
getPackageName() → Future<String?>
Returns FlutterFFmpeg package name.
getPlatform() → Future<String?>
Returns platform name in which library is loaded.
handleExecuteEvent(Map executeEvent) → void
handleLogEvent(Map logEvent) → void
handleStatisticsEvent(Map statisticsEvent) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerNewFFmpegPipe() → Future<String?>
Creates a new FFmpeg pipe and returns its path.
resetStatistics() → Future<void>
Resets last received statistics. It is recommended to call it before starting a new execution.
setEnvironmentVariable(String variableName, String variableValue) → Future<void>
Sets an environment variable.
setFontconfigConfigurationPath(String path) → Future<void>
Sets and overrides fontconfig configuration directory.
setFontDirectory(String fontDirectory, Map<String, String> fontNameMap) → Future<void>
Registers fonts inside the given fontDirectory, so they will be available to use in FFmpeg filters.
setLogLevel(int logLevel) → Future<void>
Sets log level.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited