PlaybackDisposition class

Used to stream data about the position of the playback as playback proceeds.

Constructors

PlaybackDisposition({Duration position = Duration.zero, Duration duration = Duration.zero})
The constructor
PlaybackDisposition.zero()
A convenience ctor. If you are using a stream builder you can use this to set initialData with both duration and postion as 0.

Properties

duration → Duration
The duration of the media.
final
hashCode → int
The hash code for this object.
no setterinherited
position → Duration
The current position within the media that we are playing.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited