Track class

Constructors

Track({String? trackPath, Uint8List? dataBuffer, String? trackTitle, String? trackAuthor, String? albumArtUrl, String? albumArtAsset, String? albumArtFile, Codec codec = Codec.defaultCodec})
The constructor

Properties

albumArtAsset ↔ String?
The asset that points to the album art of the track
getter/setter pair
albumArtFile ↔ String?
The file that points to the album art of the track
getter/setter pair
albumArtUrl ↔ String?
The URL that points to the album art of the track
getter/setter pair
codec ↔ Codec
The image that points to the album art of the track The codec of the audio file to play. If this parameter's value is null it will be set to t_CODEC.DEFAULT.
getter/setter pair
dataBuffer ↔ Uint8List?
The buffer containing the audio file to play
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackAuthor ↔ String?
The name of the author of this track
getter/setter pair
trackPath ↔ String?
The path that points to the track audio file
getter/setter pair
trackTitle ↔ String?
The title of this track
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Convert this object to a Map containing the properties of this object as values.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited