FoodEvent class

foodEvent is a special kin of food which allows to re-synchronize a stream with a player that play from a Dart Stream

Inheritance

Constructors

FoodEvent(Function on)
The constructor, specifying the callback which must be fired when synchronization is done

Properties

hashCode → int
The hash code for this object.
no setterinherited
on ↔ Function
The callback to fire when this food is synchronized with the player
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dummy(FlutterSoundPlayer player) → void
use internally by Flutter Sound
inherited
exec(FlutterSoundPlayer player) → Future<void>
Used internally by Flutter Sound
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited