TempFiles class

Constructors

TempFiles()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(TempFileLocations location, [String prefix = '']) → Future<File>
Creates a temporary file in the systems temp directory. @param subdirectory - the directory (under the temp file system) to place the file in. @param prefix - an optional prefix to prepend to the randomly generated filename.
generateRandomFileName() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited